Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(173)

Unified Diff: chrome/browser/autocomplete/autocomplete_edit_view_mac.h

Issue 209004: Use delegate protocols present in the 10.6 SDK (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src/
Patch Set: '' Created 11 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/app_modal_dialog_mac.mm ('k') | chrome/browser/autocomplete/autocomplete_edit_view_mac.mm » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/autocomplete/autocomplete_edit_view_mac.h
===================================================================
--- chrome/browser/autocomplete/autocomplete_edit_view_mac.h (revision 26448)
+++ chrome/browser/autocomplete/autocomplete_edit_view_mac.h (working copy)
@@ -17,8 +17,8 @@
#include "webkit/glue/window_open_disposition.h"
class AutocompleteEditController;
-@class AutocompleteEditHelper;
class AutocompleteEditModel;
+@class AutocompleteFieldDelegate;
class AutocompletePopupViewMac;
@class AutocompleteTextField;
class BubblePositioner;
@@ -88,7 +88,7 @@
virtual bool OnAfterPossibleChange();
virtual gfx::NativeView GetNativeView() const;
// Helper functions for use from AutocompleteEditHelper Objective-C
// class.
// Returns true if |popup_view_| is open.
@@ -176,7 +176,7 @@
AutocompleteTextField* field_; // owned by tab controller
// Objective-C object to bridge field_ delegate calls to C++.
- scoped_nsobject<AutocompleteEditHelper> edit_helper_;
+ scoped_nsobject<AutocompleteFieldDelegate> edit_helper_;
// Selection at the point where the user started using the
// arrows to move around in the popup.
« no previous file with comments | « chrome/browser/app_modal_dialog_mac.mm ('k') | chrome/browser/autocomplete/autocomplete_edit_view_mac.mm » ('j') | no next file with comments »
@@ -88,7 +88,7 @@
virtual bool OnAfterPossibleChange();
virtual gfx::NativeView GetNativeView() const;
- // Helper functions for use from AutocompleteEditHelper Objective-C
+ // Helper functions for use from AutocompleteFieldDelegate Objective-C
// class.
// Returns true if |popup_view_| is open.

Powered by Google App Engine
This is Rietveld 408576698